@@ -7,12 +7,11 @@ use Getopt::Long qw(GetOptionsFromArray :config auto_abbrev
 File::Spec::Functions->import(qw(catfile catdir));
 
 our $AUTHORITY = 'cpan:BEROV';
-our $VERSION   = '0.04';
+our $VERSION   = '0.05';
 
 has args => sub { {} };
-has description =>
-  'Generate resources from database for your application';
-has usage => sub { shift->extract_usage };
+has description     => 'Generate resources from database for your application';
+has usage           => sub { shift->extract_usage };
 has _templates_path => '';
 has '_db_helper';
 
